summaryrefslogtreecommitdiffstats
path: root/chrome/common/extensions/feature.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/common/extensions/feature.h')
-rw-r--r--chrome/common/extensions/feature.h16
1 files changed, 13 insertions, 3 deletions
diff --git a/chrome/common/extensions/feature.h b/chrome/common/extensions/feature.h
index 61a96a5..749f4b3 100644
--- a/chrome/common/extensions/feature.h
+++ b/chrome/common/extensions/feature.h
@@ -22,11 +22,21 @@ namespace extensions {
class Feature {
public:
// The JavaScript contexts the feature is supported in.
+ // TODO(kalman): s/PRIVILEGED/BLESSED_EXTENSION/
enum Context {
UNSPECIFIED_CONTEXT,
- PRIVILEGED_CONTEXT, // A context in a privileged extension process.
- UNPRIVILEGED_CONTEXT, // A context in a normal, unprivileged renderer.
- CONTENT_SCRIPT_CONTEXT // A context from a content script.
+
+ // A context in a privileged extension process.
+ PRIVILEGED_CONTEXT,
+
+ // A context in a normal, unprivileged renderer.
+ UNPRIVILEGED_CONTEXT,
+
+ // A context from a content script.
+ CONTENT_SCRIPT_CONTEXT,
+
+ // A normal web page. This should have an associated URL matching pattern.
+ WEB_PAGE_CONTEXT,
};
// The location required of extensions the feature is supported in.